summaryrefslogtreecommitdiffstats
path: root/src/usr/hwpf/hwp/dram_training
diff options
context:
space:
mode:
authorThi Tran <thi@us.ibm.com>2016-05-26 14:54:34 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2016-06-13 16:48:04 -0400
commit6a4bf623a6f2c7c969431944cd684c8d98bcb1ae (patch)
tree93c55b1f98dfff68fabb35ee7a2d3e075f7a80b5 /src/usr/hwpf/hwp/dram_training
parenta4edd934b26877603b9e024182d98fb210fba8fc (diff)
downloadtalos-hostboot-6a4bf623a6f2c7c969431944cd684c8d98bcb1ae.tar.gz
talos-hostboot-6a4bf623a6f2c7c969431944cd684c8d98bcb1ae.zip
Attribute Review - Nest
Change-Id: I6af714a8975122a4e83c955a21913ede0d643453 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/23164 Tested-by: Jenkins Server Tested-by: PPE CI Tested-by: Hostboot CI Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com> Reviewed-by: Joseph J. McGill <jmcgill@us.ibm.com> Reviewed-by: Jennifer A. Stofer <stofer@us.ibm.com> Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/23168 Tested-by: FSP CI Jenkins
Diffstat (limited to 'src/usr/hwpf/hwp/dram_training')
-rw-r--r--src/usr/hwpf/hwp/dram_training/mem_pll_setup/cen_mem_pll_initf.C8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/usr/hwpf/hwp/dram_training/mem_pll_setup/cen_mem_pll_initf.C b/src/usr/hwpf/hwp/dram_training/mem_pll_setup/cen_mem_pll_initf.C
index 728a83c28..1e4c9fb6f 100644
--- a/src/usr/hwpf/hwp/dram_training/mem_pll_setup/cen_mem_pll_initf.C
+++ b/src/usr/hwpf/hwp/dram_training/mem_pll_setup/cen_mem_pll_initf.C
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2012,2014 */
+/* Contributors Listed Below - COPYRIGHT 2012,2016 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -339,11 +339,11 @@ fapi::ReturnCode cen_mem_pll_initf(const fapi::Target & i_target)
FAPI_ERR("Failed to get attribute: ATTR_MSS_FREQ.");
break;
}
- // ATTR_FREQ_PB is a "system" attribute, so use NULL as the target.
- rc = FAPI_ATTR_GET( ATTR_FREQ_PB, NULL, nest_freq);
+ // ATTR_FREQ_PB_MHZ is a "system" attribute, so use NULL as the target.
+ rc = FAPI_ATTR_GET( ATTR_FREQ_PB_MHZ, NULL, nest_freq);
if (rc)
{
- FAPI_ERR("Failed to get attribute: ATTR_FREQ_PB.");
+ FAPI_ERR("Failed to get attribute: ATTR_FREQ_PB_MHZ.");
break;
}
OpenPOWER on IntegriCloud